library(ggplot2)
# ******NOTE********: requires running the Potential and Culture Coinfection Code in files  
# code_potential_coinfection.R and code_culture_coinfection.R

#Cross-data set supplementary analyses

#Ecosystem Habitat

#Ecosystem Plots for Potential and Culture Coinfection

potential_ecosystem <- ggplot(data=phages_infecting_complete, aes(x=ECOSYSTEM, y=prop_infecting)) +
  geom_boxplot() + 
  geom_point(aes(colour=studies), position=position_jitter(width=0.2, height=0.02), alpha=0.75) +
  coord_flip()  + theme(legend.position="none") +
  labs(title = "A. Ecosystem in Potential Coinfection")

culture_ecosystem <- ggplot(aes(ECOSYSTEM, extrachromosomal), data=subset(culture_coinfection_gold_metadata_full, ECOSYSTEM != "NA")) +
  geom_boxplot() + 
  geom_point(aes(colour=Host), position=position_jitter(width=0.2, height=0.3), alpha=0.25) +
  coord_flip()  + theme(legend.position="none") +
  labs(title = "B. Ecosystem in Culture Coinfection")

#Figure S5
grid.arrange(potential_ecosystem, culture_ecosystem, nrow = 2)

#Ecosystem Summary Stats for Potential and Culture Coinfection

#Potential Coinfection
with(phages_infecting_complete, tapply(prop_infecting, ECOSYSTEM, mean))
with(phages_infecting_complete, tapply(prop_infecting, ECOSYSTEM, sd))
with(phages_infecting_complete, tapply(prop_infecting, ECOSYSTEM, length))
#Engineered   Environmental Host-associated 
#0.4183413       0.2869016       0.5118920  mean
#0.3074970       0.2796728       0.4133641  sd
#330             302             373        sample size

with(culture_coinfection_gold_metadata_full, tapply(extrachromosomal, ECOSYSTEM, mean))
with(culture_coinfection_gold_metadata_full, tapply(extrachromosomal, ECOSYSTEM, sd))
with(culture_coinfection_gold_metadata_full, tapply(extrachromosomal, ECOSYSTEM, length))
#Engineered   Environmental Host-associated 
#1.3202847       0.9488889       1.3858010  mean
#1.4382211       0.9669649       1.6208361  sd
#281             450             4282       sample size

#Table S2
#Differences in percentage terms in potential coinfection
(c(0.4183413,       0.2869016,       0.5118920)/0.5118920)*100
#81.72452  56.04729 100.00000
#Differences in percentage terms in culture coinfection
(c(1.3202847,       0.9488889,       1.3858010)/1.3858010)*100
#[1] 95.27232  68.47223 100.00000


#Redrawing plots for Host Energy Source
potential_energy_source <- ggplot(data=phages_infecting_complete, aes(x=reorder(Bacterialtrophy, prop_infecting), y=prop_infecting)) + theme(legend.position="none") + 
  geom_point(aes(colour=Bacterialtrophy), position=position_jitter(width=0.3, height=0.01), alpha=0.65) + scale_y_continuous(breaks=seq(0, 20, 1)) +
  geom_errorbar(stat = "hline", yintercept = "mean", size=1, width=0.8, aes(ymax=..y..,ymin=..y..)) + coord_flip() +
  scale_color_manual(values = c("darkmagenta","limegreen")) +
  xlab("Bacterial Trophy") + ylab("Prop. of tested phage infecting") +
  labs(title = "A. Host Energy Source in Potential Coinfection")

#Excluding Mixotrophs, which have same average as Heterotrophs, see below
culture_energy_source <- ggplot(aes(ENERGY_SOURCE, extrachromosomal), data=subset(culture_coinfection_gold_metadata_full, ENERGY_SOURCE != "NA" & ENERGY_SOURCE != "Mixotroph")) + theme(legend.position="none") + 
  geom_point(aes(colour=ENERGY_SOURCE), position=position_jitter(width=0.3, height=0.25), alpha=0.65) + scale_y_continuous(breaks=seq(0, 20, 1)) +
  geom_errorbar(stat = "hline", yintercept = "mean", size=1, width=0.8, aes(ymax=..y..,ymin=..y..)) + coord_flip() +
  scale_color_manual(values = c("limegreen", "darkmagenta")) +
  xlab("Host energy source") + ylab("Extrachromosomal viruses infecting") +
  labs(title = "B. Host Energy Source in Culture Coinfection")

#Figure S6
grid.arrange(potential_energy_source, culture_energy_source, nrow = 2)

#Summary Statistics of Hetero and autotrophy
#Culture Coinfections
#Mean
with(culture_coinfection_gold_metadata_full, tapply(extrachromosomal, ENERGY_SOURCE, mean))
#Autotroph Heterotroph   Mixotroph 
#1.034483    1.342034    1.333333 
#Standard Deviation
with(culture_coinfection_gold_metadata_full, tapply(extrachromosomal, ENERGY_SOURCE, sd))
#Autotroph Heterotroph   Mixotroph 
#0.7310833   1.5722975   0.5773503
#Sample Size
with(culture_coinfection_gold_metadata_full, tapply(extrachromosomal, ENERGY_SOURCE, length))
#Autotroph Heterotroph   Mixotroph 
#29        5134           3 

#Potential Coinfection
#Mean
with(phages_infecting_complete, tapply(prop_infecting, Bacterialtrophy, mean))
#heterotrophic photosynthetic 
#0.4317216      0.2529349 
#Standard Deviation
with(phages_infecting_complete, tapply(prop_infecting, Bacterialtrophy, sd))
#heterotrophic photosynthetic 
#0.3583445      0.3056641 
#Sample Size
with(phages_infecting_complete, tapply(prop_infecting, Bacterialtrophy, length))
#heterotrophic photosynthetic 
#930             59 

#Difference between heterotrophy and autotrophy in culture and potential coinfection data sets
#Potential Coinfection
(.2529349/.4317216)*100
#[1] 58.5875
#Culture Coinfection
(1.034483/1.342034)*100
#[1] 77.08322
