###### Need to add metadata to test factors affecting culture coinfection (Section 4 of code) ######
## This involves two steps. Preparing the Roux metadata and then preparing the GOLD metadata for importing
# GOLD metadata= More culture coinfection metadata from Departent of Energy's Joint Genome Institute 
# Genomes Online (GOLD) database 


#This is starting data frame
View(curated_coinfections_all)

#Split taxonomic affilitation of the host. Use abbreviated names to prevent conflict with existing columns
# using Order, Family, and Genus for phages

curated_coinfections_all_taxonomy <- separate(curated_coinfections_all, Taxonomic.affiliation.of.host.genome, c("Dom", "Phyl", "Class", "Ord", "Fam", "Gen"), sep=";")
View(curated_coinfections_all_taxonomy)

#Now have to cast to get tidy data set where each row is 1 host
View(as.data.frame(table(curated_coinfections_all_taxonomy$Host.x)))

#This data frame is produced just to check whether I'm getting same total
hosts_coinfection <- as.data.frame(table(curated_coinfections_all_taxonomy$Host.x))
names(hosts_coinfection) <- c("Host", "Grand Total")

#Redoing
#How many of each nucleic acid type (dsDNA or ssDNA) is coinfecting each host?
nucleic_coinfection <- as.data.frame(table(curated_coinfections_all$Nucleic, curated_coinfections$Host))
View(nucleic_coinfection)

#Adjust names
colnames(nucleic_coinfection) <- c("Nucleic", "Host", "Viruses")

#Now have to cast to get tidy data set where each row is 1 host 
nucleic_coinfection_cast <- dcast(nucleic_coinfection, Host~Nucleic)
head(nucleic_coinfection_cast)
#Looks good!

#Adjust names
colnames(nucleic_coinfection_cast) <- c("Host", "dsDNA", "ssDNA", "unclassified", "unclassified_phage")

head(nucleic_coinfection_cast)
#merge unclassified all into 1 column
nucleic_coinfection_cast <- mutate(nucleic_coinfection_cast, unclass = unclassified + unclassified_phage)

#Drop the two original unclassified columns
nucleic_coinfection_cast <- nucleic_coinfection_cast[ , c("Host", "dsDNA", "ssDNA", "unclass")]

#Total
nucleic_coinfection_cast <- mutate(nucleic_coinfection_cast, total = dsDNA + ssDNA + unclass)

View(inner_join(hosts_coinfection, nucleic_coinfection_cast, by = "Host"))

#Check if Grand Total matches the total 
xyz <- hosts_coinfection$"Grand Total" == nucleic_coinfection_cast$total
which(xyz == FALSE)
#[1] 161
#found one FALSE at 161. 

#What host is that in original data set?
s <- inner_join(hosts_coinfection, nucleic_coinfection_cast, by = "Host")
s[161, ]
#                             Host Grand Total dsDNA ssDNA unclass total
#161 Bacteroides ovatus CL03T12C18           2     1     0       0     1

View(subset(curated_coinfections_all_taxonomy, Host.x == "Bacteroides ovatus CL03T12C18"))
#The nucleic acid type not noted here or in the original file from Roux et al (Supplementary_Information_Table_1_Sequence_summary.xls),
# but clearly a coinfection

#Therefore adding manually to unclass, becuase unclassified by definition and not including would screw
# up the total coinfection for this host
nucleic_coinfection_cast[161, ]$unclass <- 1
#Now updating total
nucleic_coinfection_cast[161, ]$total <- 2
#Check that it was updated
nucleic_coinfection_cast[161, ]$unclass#Yes
xyz <- hosts_coinfection$"Grand Total" == nucleic_coinfection_cast$total
which(xyz == FALSE)
#integer(0)
#Double yes

#Now same with infection mode, i.e. extrachromosomal or prophage: Make a cross tabulation of the 
# infection modes (i.e extrachromosomal or integrated prophage) in coinfected hosts  
coinfection_infection_mode <- as.data.frame(table(curated_coinfections_all$Sequence.type, curated_coinfections_all$Host.x))
View(coinfection_infection_mode)

#Adjust names
colnames(coinfection_infection_mode) <- c("Mode", "Host", "Viruses")

## Cast data set to manipulate data more easily
coinfection_infection_mode_cast <- dcast(coinfection_infection_mode, Host~Mode)
head(coinfection_infection_mode_cast)


View(inner_join(hosts_coinfection, coinfection_infection_mode_cast, by = "Host"))
l <- inner_join(hosts_coinfection, coinfection_infection_mode_cast, by = "Host")
j <- l$"Grand Total" == l$total
which(j == FALSE)
#integer(0)
##Looks good!!

#So now, we proceed to join each one sequentially - Just a test for now, need to add more than
# just host name from the original DF

#First, nucleic acids
hosts_coinfection <- inner_join(hosts_coinfection, nucleic_coinfection_cast, by = "Host")
head(hosts_coinfection)

#Second, infection mode
hosts_coinfection <- inner_join(hosts_coinfection, coinfection_infection_mode_cast, by = "Host")
head(hosts_coinfection)

#Double check that it all adds up!
xyz <- hosts_coinfection$"Grand Total" == hosts_coinfection$total.x
which(xyz == FALSE)
#integer(0)
xyz <- hosts_coinfection$"Grand Total" == hosts_coinfection$total.y
which(xyz == FALSE)
#integer(0)
#Looks good!!

#Now drop the total columns
hosts_coinfection <- hosts_coinfection[c(1:5, 7, 8)]
head(hosts_coinfection)
colnames(hosts_coinfection)[2] <- "Grand.Total"


#Start from BIG data frame. Then need to subtract curated coinfections and merge them in somehow
# MAYBE before starting all this, I can also figure out what will be the link between both data sets  
# The link between data sets (GOLD and Roux) is the GI/SeqID 


#OK, first let's get the Roux side of things settled
###

#Start from big data frame (see 1. Data Sources and Preparing data in culture_coinfection_gold.R) that has 
# all the infections detected by Virsorter
View(big_data_frame)

#Split the taxonomic ranks
big_data_frame <- separate(big_data_frame, Taxonomic.affiliation.of.host.genome, c("Dom", "Phyl", "Class", "Ord", "Fam", "Gen"), sep=";")

#Create Table
View(as.data.frame(table(big_data_frame$Host)))

#This data frame is just to check whether I'm getting same total
hosts_single_infection <- as.data.frame(table(big_data_frame$Host))
names(hosts_single_infection) <- c("Host", "Grand Total")
head(hosts_single_infection)

#Now do an anti-join
View(anti_join(hosts_single_infection, hosts_coinfection, by="Host"))
nrow(hosts_single_infection) - nrow(hosts_coinfection)
#[1] 3047

nrow(anti_join(hosts_single_infection, hosts_coinfection, by="Host"))
#[1] 3047

#Now do the same as before with curated coinfection data set, but with single coinfection

nucleic_single_infection <- as.data.frame(table(big_data_frame$Nucleic, big_data_frame$Host))
View(nucleic_single_infection)

#Adjust names
colnames(nucleic_single_infection) <- c("Nucleic", "Host", "Viruses")

#Now have to cast to get tidy data set where each row is 1 host 
nucleic_single_infection_cast <- dcast(nucleic_single_infection, Host~Nucleic)
head(nucleic_single_infection_cast)
#Looks good!

#Adjust names
colnames(nucleic_single_infection_cast) <- c("Host", "dsDNA", "ssDNA", "unclassified", "unclassified_phage")

head(nucleic_single_infection_cast)
#merge unclassified all into 1 column
nucleic_single_infection_cast <- mutate(nucleic_single_infection_cast, unclass = unclassified + unclassified_phage)

#Drop the two original unclassified columns
nucleic_single_infection_cast <- nucleic_single_infection_cast[ , c("Host", "dsDNA", "ssDNA", "unclass")]

#Total
nucleic_single_infection_cast <- mutate(nucleic_single_infection_cast, total = dsDNA + ssDNA + unclass)

View(inner_join(hosts_single_infection, nucleic_single_infection_cast, by = "Host"))

xyz <- hosts_single_infection$"Grand.Total" == nucleic_single_infection_cast$total
which(xyz == FALSE)
#[1] 200 384 386 388 389 395 404 405
#CHECK THESE!!!!

s <- inner_join(hosts_single_infection, nucleic_single_infection_cast, by = "Host")
as.vector(s[c(200, 384, 386, 388, 389, 395, 404, 405), "Host"])

View(subset(big_data_frame, Host == "Acinetobacter sp. RUH2624"))
View(subset(big_data_frame, Host == "Bacteroides caccae CL03T12C61")) 
View(subset(big_data_frame, Host == "Bacteroides clarus YIT 12056")) 
View(subset(big_data_frame, Host == "Bacteroides dorei CL03T12C01"))
View(subset(big_data_frame, Host == "Bacteroides eggerthii 1_2_48FAA")) 
View(subset(big_data_frame, Host == "Bacteroides ovatus CL03T12C18"))
View(subset(big_data_frame, Host == "Bacteroides sp. D1"))
View(subset(big_data_frame, Host == "Bacteroides sp. D22"))
#The nucleic acid type not noted, so put down manually as unclassified

#Therefore adding manually to unclass, becuase unclassified by definition and not including would screw
# up the total coinfection for this host
nucleic_single_infection_cast[c(200, 384, 386, 388, 389, 395, 404, 405), ]$unclass <- 1
#Now updating total
nucleic_single_infection_cast[c(200, 384, 386, 388, 389, 395, 404, 405), ]$total <- 1
#Check that it was updated
xyz <- hosts_single_infection$"Grand.Total" == nucleic_single_infection_cast$total
which(xyz == FALSE)
#395
nucleic_single_infection_cast[395, ]
#Right, this one also has a dsDNA, so need to update total to 2
nucleic_single_infection_cast[395, ]$total <- 2

#Check again
xyz <- hosts_single_infection$"Grand.Total" == nucleic_single_infection_cast$total
which(xyz == FALSE)
#integer(0)

#Now let's do infection mode 
single_infection_mode <- as.data.frame(table(big_data_frame$Sequence.type, big_data_frame$Host))
View(single_infection_mode)

#Adjust names
colnames(single_infection_mode) <- c("Mode", "Host", "Viruses")

## Cast data set to manipulate data more easily
single_infection_mode_cast <- dcast(single_infection_mode, Host~Mode)
head(single_infection_mode_cast)

#Add a total column
single_infection_mode_cast <- mutate(single_infection_mode_cast, total = extrachromosomal + prophage)

xyz <- hosts_single_infection$"Grand.Total" == single_infection_mode_cast$total
which(xyz == FALSE)
#integer(0)
#All good!!!

#So now, we proceed to join each one sequentially for the single infections - Just a test for now, need to 
# add more than just host name from the original DF

#First, nucleic acids
hosts_single_infection <- inner_join(hosts_single_infection, nucleic_single_infection_cast, by = "Host")
head(hosts_single_infection)

#Second, infection mode
hosts_single_infection <- inner_join(hosts_single_infection, single_infection_mode_cast, by = "Host")
head(hosts_single_infection)

#Now drop the total columns
hosts_single_infection <- hosts_single_infection[c(1:5, 7, 8)]
head(hosts_single_infection)
colnames(hosts_single_infection)[2] <- "Grand.Total"

#Now need to do an anti-join to remove curated coinfections from big data set and then add just the 
# curated coinfections

hosts_single_infection_only <- anti_join(hosts_single_infection, hosts_coinfection, by="Host")
nrow(hosts_single_infection) - nrow(hosts_coinfection)
nrow(hosts_single_infection_only)

#Now the remaining 3,047 hosts have some putative coinfections, but those are not high-confidence 
# coinfections in Roux et al. 2015 because of mis-assembled Caudovirales genomes, among other reasons

#So going to manually change Grand Total to 1, to reflect this "conservative" assigning of coinfections

View(subset(hosts_single_infection_only, Grand.Total > 1))
#change all to one
hosts_single_infection_only[hosts_single_infection_only$Grand.Total >1, "Grand.Total"] <- 1
nrow(subset(hosts_single_infection_only, Grand.Total > 1))
#[1] 0
#No 1's now.

culture_coinfection <- rbind(hosts_coinfection, hosts_single_infection_only)
#This is the *ALMOST* final data set for the regression analysis 

#Quick model to check
model_temp <- glm(Grand.Total ~ ssDNA + prophage + dsDNA + extrachromosomal, family="poisson", data=culture_coinfection)
summary(model_temp)

#But wait, can't really use these variables because the total comes from them....right??

#Now, let's try to add the taxonomic information

taxonomy_information <- big_data_frame[c("Dom",  "Phyl",  "Class",	"Ord", 	"Fam",	"Gen", "Host")]

View(left_join(culture_coinfection, taxonomy_information, by="Host"))
#This works, but have to eliminate replicate rows

culture_coinfection <- left_join(culture_coinfection, taxonomy_information, by="Host")

#Eliminate replicate rows: test
View(distinct(culture_coinfection))

#Eliminate replicate rows
culture_coinfection <- distinct(culture_coinfection)
#Check
nrow(culture_coinfection)


#### Now with all the Roux data integrated, lets go on to integrate the GOLD data.

#The best bet here is going to be to use the Host names (which I originally used in building the query)
# and use that to get the GOLD ID's and then link to the GOLD data

gold_ncbi_join_ALL <- read.csv("data/gold_ncbi_join_ALL.csv")
head(gold_ncbi_join_ALL)
colnames(gold_ncbi_join_ALL)

#Now select the columns we need and do a join so we can have an ID to join with the GOLD data
gold_linker <- gold_ncbi_join_ALL[c(3, 4)]

#Change column names to match for join
colnames(gold_linker) <- c("Host", "GOLDSTAMP")
head(gold_linker)

View(left_join(culture_coinfection, gold_linker, by="Host"))

culture_coinfection_gold <- left_join(culture_coinfection, gold_linker, by="Host")

#More culture coinfection metadata from Departent of Energy's Joint Genome Institute Genomes Online database 
# I generated a list of GI's for the hosts. T.B.K Reddy of JGI-GOLD used this list to query the GOLD database
# and sent me a file on 06-15-16 , which is in data/unprocessed/gold_ncbi_join_ID_TBKR_06142016.xls

library(ggplot2)
library(XLConnect)
library(reshape2)
library(gridExtra)
library(dplyr)

#First let's get the Excel file generated by Reddy on 06/14/2016 (emailed 06/15/2016)

#Import GOLD metadata
excel_gold <- loadWorkbook(filename = "data/unprocessed/gold_ncbi_join_ID_TBKR_06142016.xls")
sheets_gold <- readWorksheet(excel_gold, sheet = getSheets(excel_gold), header = TRUE)
names(sheets_gold)

#Import each of the relevant sheets
link_gold <- readWorksheet(excel_gold, sheet="gold_ncbi_join_ID.csv", header=TRUE)
#This one is relevant because it provides link between Roux data and GOLD metadata
main_gold <- readWorksheet(excel_gold, sheet="GOLD_Data_8190_Proj", header=TRUE)
habitat_gold <- readWorksheet(excel_gold, sheet="Habitat", header=TRUE)
energy_gold <- readWorksheet(excel_gold, sheet="Energy_source", header=TRUE)
disease_gold <- readWorksheet(excel_gold, sheet="Disease", header=TRUE)

#Note that for the mail-gold sheet, it is the second 'GOLD_ID' column that has the ID's that are shared in
# the next tables. ID's start in 'Go...' instead of 'Gp...'
# So let's change first column name to be something different
names(main_gold) <- c("GOLD_ID_old", "GOLD_ID", "NCBI_TAXONOMY_ID", "ORGANISM_NAME", "PROJECT_NAME", 
                      "SAMPLE_COLLECTION_SITE", "GEOGRAPHIC_LOCATION", "HOST_NAME", "HOST_TAXONOMY_ID",
                      "ECOSYSTEM", "ECOSYSTEM_CATEGORY", "ECOSYSTEM_TYPE", "ECOSYSTEM_SUBTYPE", "SPECIFIC_ECOSYSTEM")
names(main_gold)
#worked!!!

#Let's do several successive joins, culminating in a mega-table that has *all* the GOLD metadata
#Note that this join starts with main_gold as the left table
all_gold <- left_join(main_gold, habitat_gold, by = "GOLD_ID")

#Note that from here on I have changed left table to all_gold to make additions recursive
#First need to change an error in the energy table that lists the header for energy source as 'HABITAT'
names(energy_gold) <- c("GOLD_ID", "ENERGY_SOURCE")
all_gold <- left_join(all_gold, energy_gold, by = "GOLD_ID")

#First need to change same error in the disease table that lists the header for disease as 'HABITAT'
names(disease_gold) <- c("GOLD_ID", "DISEASE")
all_gold <- left_join(all_gold, disease_gold, by = "GOLD_ID")

#Check the work. All looks good.
View(all_gold)
#Need to get the GI's to link back to the Roux data set
#Use first sheet from Excel workbook with and use GOLD_ID_old as the link to bring in the GI + NCBI TaxID
head(link_gold)

#Keep only the columns I'll use and rename colnames go they correspond for the join
link_gold <- link_gold[c(1, 3:4)]

#Now change name of GOLDSTAMP to "GOLD_ID_old"
names(link_gold)[3] <- "GOLD_ID_old"

#Now, left join to have everything we need from GOLD metadata in one place
all_gold <- left_join(all_gold, link_gold, by = "GOLD_ID_old")

#Just how much empty metadata do we have?
nrow(all_gold)
##[1] 8190

nrow(all_gold[is.na(all_gold$ECOSYSTEM),])
##[1] 4218
#Yikes!

nrow(all_gold[is.na(all_gold$ENERGY_SOURCE),])
##[1] 7351
#double yikes!!

nrow(all_gold[is.na(all_gold$HABITAT),])
##[1] 5761

nrow(all_gold[is.na(all_gold$DISEASE),])
##[1] 6344

#Next step is to link 'all_gold' df to the taxonomy information on 'curated_coinfections_all_taxonomy' using 
# 'organism' as link.
#Finally, get the data frame with *any* NA's and export it to fill it in by hand

View(all_gold)
View(culture_coinfection_gold)

#Need to add GOLD data to see how much missing data we have
# The duplicate rows are because some hosts have >1 gold project.

#Adjust GOLD ID to match
colnames(culture_coinfection_gold)[14] <- "GOLD_ID_old"

#And there she is!
culture_coinfection_gold <- left_join(culture_coinfection_gold, all_gold, by="GOLD_ID_old")
View(culture_coinfection_gold)

#Check if the 'Host' and 'organism' columns are the same
xyz <- culture_coinfection_gold$Host == culture_coinfection_gold$organism
which(xyz == FALSE)
#integer(0)
#yep, only some NA's where no GOLD record was found

#Sort to see organisms that have 2 Gold projects. Can use one entry if metadata is deficient in other
culture_coinfection_gold_sorted <- culture_coinfection_gold[order(culture_coinfection_gold$Host), ]

#Let's get a handle on which columns are going to be best to use for ecology
colnames(culture_coinfection_gold)

#ECOSYSTEM
ggplot(aes(ECOSYSTEM, Grand.Total), data=culture_coinfection_gold) + geom_boxplot() + coord_flip() +
  geom_point() + theme(legend.position="none") + geom_point(aes(colour=ECOSYSTEM), position=position_jitter(width=0.2, height=0.02), alpha=0.25)
#Yes

#ECOSYSTEM_CATEGORY
ggplot(aes(ECOSYSTEM_CATEGORY, Grand.Total), data=culture_coinfection_gold) + geom_boxplot() + coord_flip() +
  geom_point() + theme(legend.position="none") + geom_point(aes(colour=ECOSYSTEM_CATEGORY), position=position_jitter(width=0.2, height=0.02), alpha=0.25)
#Yes

#ECOSYSTEM_TYPE
ggplot(aes(ECOSYSTEM_TYPE, Grand.Total), data=culture_coinfection_gold) + geom_boxplot() + coord_flip() +
  geom_point() + theme(legend.position="none") + geom_point(aes(colour=ECOSYSTEM_TYPE), position=position_jitter(width=0.2, height=0.02), alpha=0.25)
#maybe

#ECOSYSTEM_SUBTYPE
ggplot(aes(ECOSYSTEM_SUBTYPE, Grand.Total), data=culture_coinfection_gold) + geom_boxplot() + coord_flip() +
  geom_point() + theme(legend.position="none") + geom_point(aes(colour=ECOSYSTEM_SUBTYPE), position=position_jitter(width=0.2, height=0.02), alpha=0.25)
#nope

#SPECIFIC_ECOSYSTEM
ggplot(aes(SPECIFIC_ECOSYSTEM, Grand.Total), data=culture_coinfection_gold) + geom_boxplot() + coord_flip() +
  geom_point() + theme(legend.position="none") + geom_point(aes(colour=SPECIFIC_ECOSYSTEM), position=position_jitter(width=0.2, height=0.02), alpha=0.25)
#nope

#HABITAT
ggplot(aes(HABITAT, Grand.Total), data=culture_coinfection_gold) + geom_boxplot() + coord_flip() +
  geom_point() + theme(legend.position="none") + geom_point(aes(colour=HABITAT), position=position_jitter(width=0.2, height=0.02), alpha=0.25)
#Nope!!!!!

#ENERGY_SOURCE
ggplot(aes(ENERGY_SOURCE, Grand.Total), data=culture_coinfection_gold) + geom_boxplot() + coord_flip() +
  geom_point() + theme(legend.position="none") + geom_point(aes(colour=ENERGY_SOURCE), position=position_jitter(width=0.2, height=0.02), alpha=0.25)
#Yes! Will need some post-processing of text, but should be good. 

#DISEASE
ggplot(aes(DISEASE, Grand.Total), data=culture_coinfection_gold) + geom_boxplot() + coord_flip() +
  geom_point() + theme(legend.position="none") + geom_point(aes(colour=DISEASE), position=position_jitter(width=0.2, height=0.02), alpha=0.25)
#NOPE!!

#Check how much work ahead of myself!
length(which(is.na(culture_coinfection_gold$ECOSYSTEM) == TRUE))
#[1] 4567
length(which(is.na(culture_coinfection_gold$ECOSYSTEM_CATEGORY) == TRUE))
#[1] 4964
#yikes
length(which(is.na(culture_coinfection_gold$ENERGY_SOURCE) == TRUE))
#[1] 7612
#double yikes!

#Now export this bad boy so I can do the data entry
write.csv(culture_coinfection_gold_sorted, file = "outputs/culture_coinfection_gold.csv", sep = ",", row.names=FALSE)
#After data entry this file was renamed to culture_coinfection_gold_metadata.csv and placed in data/ folder
# This is the file imported in Section 1 of code_culture_coinfection.R